@@ -1,8 +1,8 @@
 #' Calibration performance: ggplot version
 #'
-#' The function \code{valProbggplot} is an adaptation of \code{\link{val.prob}} from Frank Harrell's rms package,
+#' The function \code{valProbggplot} is an adaptation of \code{\link[rms]{val.prob}} from Frank Harrell's rms package,
 #' \url{https://cran.r-project.org/package=rms}. Hence, the description of some of the functions of \code{valProbggplot}
-#' come from the the original \code{\link{val.prob}}.
+#' come from the the original \code{\link[rms]{val.prob}}.
 #' \cr \cr The key feature of \code{valProbggplot} is the generation of logistic and flexible calibration curves and related statistics.
 #' When using this code, please cite: Van Calster, B., Nieboer, D., Vergouwe, Y., De Cock, B., Pencina, M.J., Steyerberg,
 #' E.W. (2016). A calibration hierarchy for risk models was defined: from utopia to empirical data. \emph{Journal of Clinical Epidemiology},
@@ -10,7 +10,7 @@
 #'
 #' @inheritParams rms::val.prob
 #' @param smooth \code{"loess"} generates a flexible calibration curve based on \code{\link{loess}},
-#'  \code{"rcs"} generates a calibration curves based on restricted cubic splines (see \code{\link{rcs}} and
+#'  \code{"rcs"} generates a calibration curves based on restricted cubic splines (see \code{\link[rms]{rcs}} and
 #'  \code{\link[Hmisc]{rcspline.plot}}), \code{"none"} suppresses the flexible curve. We recommend to use loess unless N is large,
 #'   for example N>5000. Default is \code{"loess"}.
 #' @param CL.smooth \code{"fill"} shows pointwise 95\% confidence limits for the flexible calibration curve with a gray
@@ -27,7 +27,7 @@
 #'  \code{FALSE} suppresses the presentation of statistics in the figure. A \code{c()} list of specific stats shows the specified
 #'  stats. The key stats which are also mentioned in this paper are \code{"C (ROC)"} for the c statistic, \code{"Intercept"} for the
 #'  calibration intercept, \code{"Slope"} for the calibration slope, and \code{"ECI"} for the estimated calibration index
-#'  (Van Hoorde et al, 2015). The full list of possible statistics is taken from \code{\link{val.prob}}
+#'  (Van Hoorde et al, 2015). The full list of possible statistics is taken from \code{\link[rms]{val.prob}}
 #'  and augmented with the estimated calibration index: \code{"Dxy", "C (ROC)", "R2", "D", "D:Chi-sq", "D:p", "U", "U:Chi-sq",
 #'   "U:p", "Q", "Brier", "Intercept", "Slope", "Emax", "Brier scaled", "Eavg", "ECI"}. These statistics are always returned by the function.
 #' @param xlim,ylim numeric vectors of length 2, giving the x and y coordinates ranges (see \code{\link{xlim}} and \code{\link{ylim}}).
@@ -144,7 +144,7 @@ valProbggplot <- function(p, y, logit, group,
                           dist.label = 0.01, line.bins = -.05, dist.label2 = .04, cutoff, length.seg = 0.85,
                           lty.ideal = 1, col.ideal = "red", lwd.ideal = 1, allowPerfectPredictions = FALSE, argzLoess = alist(degree = 2))
 {
-  call   = match.call()
+  callFn   = match.call()
   smooth = match.arg(smooth)
   if (smooth == "none")
     smooth <- "F"
@@ -195,9 +195,9 @@ valProbggplot <- function(p, y, logit, group,
   a = 1 - cl.level
 
   if (missing(p))
-    p <- 1 / (1 + exp(-logit))
+    p <- binomial()$linkinv(logit)
   else
-    logit <- log(p / (1 - p))
+    logit <- binomial()$linkfun(p)
   if (!all(y %in% 0:1)) {
     stop("The vector with the binary outcome can only contain the values 0 and 1.")
   }
@@ -245,8 +245,18 @@ valProbggplot <- function(p, y, logit, group,
 
 
   if (length(p) > 5000 & smooth == "loess") {
-    warning("Number of observations > 5000, RCS is recommended.",
-            immediate. = TRUE)
+    warning("Number of observations > 5000, RCS is recommended. Will perform a preliminary fit to see if any errors occur.", immediate. = TRUE)
+    argzLoess$formula = y ~ p
+    tmpFit = tryCatch({
+      SmFit    = do.call("loess", argzLoess)
+      cl.loess = predict(SmFit, type = "fitted", se = TRUE)
+    }, error = function(e) TRUE, warning = function(w) TRUE)
+    if(is.logical(tmpFit)) {
+      tmpmess = "Estimating the flexible calibration curve and its CI with loess resulted in errors. Smooth is set to RCS and the calibration curve is estimated using RCS."
+      warning(tmpmess, immediate. = TRUE)
+      smooth = "rcs"
+      wmess = c(wmess, tmpmess)
+    }
   }
   if (length(p) > 1000 & CL.BT == TRUE) {
     warning("Number of observations is > 1000, this could take a while...",
@@ -275,7 +285,7 @@ valProbggplot <- function(p, y, logit, group,
     Results =
       structure(
         list(
-          call = call,
+          call = callFn,
           stats = stats,
           cl.level = cl.level,
           Calibration = list(
@@ -354,7 +364,8 @@ valProbggplot <- function(p, y, logit, group,
     }
     if (smooth == "loess") {
       argzLoess$formula = y ~ p
-      SmFit = do.call("loess", argzLoess)
+      if(!exists("SmFit"))
+        SmFit = do.call("loess", argzLoess)
       Sm    = data.frame(x = unname(SmFit$x), y = SmFit$fitted)
       Sm.01 = Sm
 
@@ -393,7 +404,8 @@ valProbggplot <- function(p, y, logit, group,
           dfCL    = data.frame(x = to.pred, y = apply(res.BT, 1, quantile, 0.5), ymin = CL.BT[1, ], ymax = CL.BT[2, ])
           rownames(dfCL) = NULL
         } else {
-          cl.loess = predict(SmFit, type = "fitted", se = TRUE)
+          if(!exists("cl.loess"))
+            cl.loess = predict(SmFit, type = "fitted", se = TRUE)
           dfCL     = data.frame(x = p, ymin = with(cl.loess, fit - qnorm(1 - a / 2) * se.fit),
                                 ymax = with(cl.loess, fit + qnorm(1 - a / 2) * se.fit))
         }
@@ -426,7 +438,7 @@ valProbggplot <- function(p, y, logit, group,
       }
       colnames(Sm) = c("x", "y")
       if(exists("dfCL", envir = environment())) {
-        flexCal = if("CL.BT" %in% names(call) && call$CL.BT) list(loessFit = Sm, BootstrapConfidenceLimits = dfCL) else merge(Sm, dfCL, by = "x")
+        flexCal = if("CL.BT" %in% names(callFn) && as.logical(as.character(callFn$CL.BT))) list(loessFit = Sm, BootstrapConfidenceLimits = dfCL) else merge(Sm, dfCL, by = "x")
       } else {
         flexCal = Sm
       }
@@ -656,7 +668,7 @@ valProbggplot <- function(p, y, logit, group,
   Results =
     structure(
       list(
-        call   = call,
+        call   = callFn,
         ggPlot = gg,
         stats  = stats,
         cl.level = cl.level,
